@@ -500,7 +500,7 @@ applet_fill_cb (PanelApplet *applet,
 			G_CALLBACK (menuitem_destroy_cb), adata);
       g_signal_connect (menuitem, "activate",
 			G_CALLBACK (user_item_activate_cb), adata);
-      gtk_menu_shell_prepend (GTK_MENU_SHELL (adata->menu), menuitem);
+      gtk_menu_shell_append (GTK_MENU_SHELL (adata->menu), menuitem);
       adata->items = g_slist_prepend (adata->items, menuitem);
 
       if (active_only)
@@ -525,13 +525,13 @@ applet_fill_cb (PanelApplet *applet,
 		    G_CALLBACK (manager_user_added_cb), adata);
 
   adata->separator_item = gtk_separator_menu_item_new ();
-  gtk_menu_shell_prepend (GTK_MENU_SHELL (adata->menu), adata->separator_item);
+  gtk_menu_shell_append (GTK_MENU_SHELL (adata->menu), adata->separator_item);
   adata->items = g_slist_prepend (adata->items, adata->separator_item);
 
   adata->login_screen_item = gtk_image_menu_item_new_with_label (_("Other"));
   gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (adata->login_screen_item),
 				 gtk_image_new ());
-  gtk_menu_shell_prepend (GTK_MENU_SHELL (adata->menu),
+  gtk_menu_shell_append (GTK_MENU_SHELL (adata->menu),
 			  adata->login_screen_item);
   g_signal_connect (adata->login_screen_item, "style-set",
 		    G_CALLBACK (menuitem_style_set_cb), adata);
@@ -544,7 +544,7 @@ applet_fill_cb (PanelApplet *applet,
   adata->login_window_item = gtk_image_menu_item_new_with_label (_("Login Window"));
   gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (adata->login_window_item),
 				 gtk_image_new ());
-  gtk_menu_shell_prepend (GTK_MENU_SHELL (adata->menu),
+  gtk_menu_shell_append (GTK_MENU_SHELL (adata->menu),
 			  adata->login_window_item);
   g_signal_connect (adata->login_window_item, "style-set",
 		    G_CALLBACK (menuitem_style_set_cb), adata);
@@ -1157,7 +1157,8 @@ about_cb (BonoboUIComponent *ui_container,
   gtk_about_dialog_set_comments (GTK_ABOUT_DIALOG (about),
 				 _("A menu to quickly switch between users."));
   gtk_about_dialog_set_copyright (GTK_ABOUT_DIALOG (about),
-				  "Copyright \xc2\xa9 2004-2005 James M. Cape.");
+				  "Copyright \xc2\xa9 2004-2005 James M. Cape.\n"
+                                  "Copyright \xc2\xa9 2006 Thomas Thurman.");
 
   gtk_about_dialog_set_url_hook (about_url_hook, NULL, NULL);
   gtk_about_dialog_set_website (GTK_ABOUT_DIALOG (about),
@@ -1171,7 +1172,7 @@ about_cb (BonoboUIComponent *ui_container,
    * Thus, you should translate it to your name and email address.
    * You should also include other translators who have contributed to
    * this translation; in that case, please write each of them on a separate
-   * line seperated by newlines (\n).
+   * line separated by newlines (\n).
    */
   gtk_about_dialog_set_translator_credits (GTK_ABOUT_DIALOG (about),
 					   _("translator-credits"));
@@ -1243,7 +1244,7 @@ manager_user_added_cb (FusaManager *manager,
 		    G_CALLBACK (menuitem_destroy_cb), adata);
   g_signal_connect (menuitem, "activate",
 		    G_CALLBACK (user_item_activate_cb), adata);
-  gtk_menu_shell_prepend (GTK_MENU_SHELL (adata->menu), menuitem);
+  gtk_menu_shell_append (GTK_MENU_SHELL (adata->menu), menuitem);
   adata->items = g_slist_prepend (adata->items, menuitem);
 
   active_only = gconf_client_get_bool (adata->client, ACTIVE_ONLY_KEY, NULL);
